@@ -48,6 +48,7 @@ pcm_ok = None
 unique = time.time()
 serial = 0
 
+
 def get_serial():
     """
     Gets a globally unique serial number for each music change.
@@ -134,6 +135,7 @@ class MusicContext(renpy.python.RevertableObject):
 # The next channel number to be assigned.
 next_channel_number = 0
 
+
 class Channel(object):
     """
     This stores information about the currently-playing music.
@@ -324,7 +326,6 @@ class Channel(object):
             renpysound.set_volume(self.number, vol)
             self.actual_volume = vol
 
-
         # This should be set from something that checks to see if our
         # mixer is muted.
         force_stop = self.context.force_stop or (renpy.game.preferences.mute[self.mixer] and self.stop_on_mute)
@@ -344,6 +345,8 @@ class Channel(object):
         # Should we do the callback?
         do_callback = False
 
+        topq = None
+
         # This has been modified so we only queue a single sound file
         # per call, to prevent memory leaks with really short sound
         # files. So this loop will only execute once, in practice.
@@ -424,14 +427,18 @@ class Channel(object):
 
         if self.loop and not self.queue:
             for i in self.loop:
-                newq = QueueEntry(i, 0, topq.tight, True)
+                if topq is not None:
+                    newq = QueueEntry(i, 0, topq.tight, True)
+                else:
+                    newq = QueueEntry(i, 0, False, True)
+
                 self.queue.append(newq)
         else:
             do_callback = True
 
         # Queue empty callback.
         if do_callback and self.callback:
-            self.callback() # E1102
+            self.callback()  # E1102
 
         want_pause = self.context.pause or global_pause
 
@@ -444,7 +451,6 @@ class Channel(object):
 
             self.paused = want_pause
 
-
     def dequeue(self, even_tight=False):
         """
         Clears the queued music.
@@ -474,19 +480,17 @@ class Channel(object):
             if self.pan_time != self.context.pan_time:
                 self.pan_time = self.context.pan_time
                 renpysound.set_pan(self.number,
-                            self.context.pan,
-                            0)
-
+                                   self.context.pan,
+                                   0)
 
             if self.secondary_volume_time != self.context.secondary_volume_time:
                 self.secondary_volume_time = self.context.secondary_volume_time
                 renpysound.set_secondary_volume(self.number,
-                                         self.context.secondary_volume,
-                                         0)
+                                                self.context.secondary_volume,
+                                                0)
 
         if not self.queue and self.callback:
-            self.callback() # E1102
-
+            self.callback()  # E1102
 
     def fadeout(self, secs):
         """
@@ -505,7 +509,7 @@ class Channel(object):
         else:
             renpysound.fadeout(self.number, int(secs * 1000))
 
-    def enqueue(self, filenames, loop=True, synchro_start=False, fadein=0, tight=None):
+    def enqueue(self, filenames, loop=True, synchro_start=False, fadein=0, tight=None, loop_only=False):
 
         for filename in filenames:
             filename, _, _ = self.split_filename(filename, False)
@@ -514,26 +518,28 @@ class Channel(object):
         if not pcm_ok:
             return
 
-        if tight is None:
-            tight = self.tight
+        if not loop_only:
 
-        self.keep_queue += 1
+            if tight is None:
+                tight = self.tight
 
-        for filename in filenames:
-            qe = QueueEntry(filename, int(fadein * 1000), tight, False)
-            self.queue.append(qe)
+            self.keep_queue += 1
 
-            # Only fade the first thing in.
-            fadein = 0
+            for filename in filenames:
+                qe = QueueEntry(filename, int(fadein * 1000), tight, False)
+                self.queue.append(qe)
+
+                # Only fade the first thing in.
+                fadein = 0
+
+            self.wait_stop = synchro_start
+            self.synchro_start = synchro_start
 
         if loop:
             self.loop = list(filenames)
         else:
             self.loop = [ ]
 
-        self.wait_stop = synchro_start
-        self.synchro_start = synchro_start
-
     def get_playing(self):
 
         if not pcm_ok:
@@ -735,9 +741,11 @@ def get_channel(name):
 
     return rv
 
+
 def set_force_stop(name, value):
     get_channel(name).context.force_stop = value
 
+
 def init():
 
     global pcm_ok
@@ -776,7 +784,7 @@ def init():
         renpy.game.preferences.mute.setdefault(m, False)
 
 
-def quit(): #@ReservedAssignment
+def quit():  # @ReservedAssignment
 
     global pcm_ok
     global mix_ok
@@ -805,6 +813,7 @@ pcm_volume = None
 
 old_emphasized = False
 
+
 def periodic():
     """
     The periodic sound callback. This is called at around 20hz, and is
@@ -819,7 +828,6 @@ def periodic():
     if not pcm_ok:
         return False
 
-
     try:
 
         # A list of emphasized channels.
@@ -921,6 +929,7 @@ def interact():
 
     periodic()
 
+
 def rollback():
     """
     On rollback, we want to stop all the channels with non-empty sounds.
@@ -932,6 +941,7 @@ def rollback():
 
 global_pause = False
 
+
 def pause_all():
     """
     Pause all playback channels.
@@ -942,6 +952,7 @@ def pause_all():
 
     periodic()
 
+
 def unpause_all():
     """
     Unpause all playback channels.
@@ -952,15 +963,16 @@ def unpause_all():
 
     periodic()
 
+
 def sample_surfaces(rgb, rgba):
     if not renpysound:
         return
 
     renpysound.sample_surfaces(rgb, rgba)
 
+
 def advance_time():
     if not renpysound:
         return
 
     renpysound.advance_time()
-
