@@ -1,4 +1,4 @@
-# Copyright 2004-2015 Tom Rothamel <pytom@bishoujo.us>
+# Copyright 2004-2016 Tom Rothamel <pytom@bishoujo.us>
 #
 # Permission is hereby granted, free of charge, to any person
 # obtaining a copy of this software and associated documentation files
@@ -24,7 +24,7 @@ from __future__ import unicode_literals
 from __future__ import division
 from __future__ import absolute_import
 
-import renpy # @UnusedImport
+import renpy  # @UnusedImport
 from renpy.python import py_compile
 
 # Import the Python AST module, instead of the Ren'Py ast module.
@@ -59,7 +59,7 @@ pure_functions = {
     "Particles", "SnowBlossom", "Text", "ParameterizedText", "FontGroup",
     "Drag", "Alpha", "AlphaMask", "Position", "Pan", "Move", "Motion", "Revolve", "Zoom",
     "RotoZoom", "FactorZoom", "SizeZoom", "Fade", "Dissolve", "ImageDissolve",
-    "AlphaDissolve", "CropMove", "Pixellate", "OldMoveTransition",
+    "AlphaDissolve", "CropMove", "PushMove", "Pixellate", "OldMoveTransition",
     "MoveTransition", "MoveFactory", "MoveIn", "MoveOut", "ZoomInOut",
     "RevolveInOut", "MultipleTransition", "ComposeTransition", "Pause",
     "SubTransition", "ADVSpeaker", "ADVCharacter", "Speaker", "Character",
@@ -74,6 +74,14 @@ pure_functions = {
     "ui.callsinnewcontext",
     "ui.invokesinnewcontext",
     "ui.gamemenus",
+
+    # renpy.py
+
+    "renpy.version_string",
+    "renpy.version_only",
+    "renpy.version_tuple",
+    "renpy.version_name",
+    "renpy.license",
     }
 
 constants = { "config", "style" } | always_constants | pure_functions
@@ -84,6 +92,7 @@ not_constants = set()
 # The base set for the local constants.
 local_constants = set()
 
+
 def const(name):
     """
     :doc: const
@@ -167,12 +176,13 @@ class Control(object):
         self.imagemap = imagemap
 
 # Three levels of constness.
-GLOBAL_CONST = 2 # Expressions that are const everywhere.
+GLOBAL_CONST = 2  # Expressions that are const everywhere.
 LOCAL_CONST = 1  # Expressions that are const with regard to a screen + parameters.
 NOT_CONST = 0    # Expressions that are not const.
 
 
 class DeltaSet(object):
+
     def __init__(self, base, copy=None):
         """
         Represents a set that stores its contents as differences from a base
@@ -214,6 +224,15 @@ class DeltaSet(object):
     def copy(self):
         return DeltaSet(self.base, self)
 
+    def __iter__(self):
+
+        for i in self.base:
+            if i not in self.removed:
+                yield i
+
+        for i in self.added:
+            yield i
+
 
 class Analysis(object):
     """
@@ -301,11 +320,10 @@ class Analysis(object):
             if not i.at_fixed_point():
                 return False
 
-
         if (self.not_constant.changed or
-            self.global_constant.changed or
-            self.local_constant.changed or
-            self.pure_functions.changed):
+                self.global_constant.changed or
+                self.local_constant.changed or
+                self.pure_functions.changed):
 
             self.not_constant.changed = False
             self.global_constant.changed = False
@@ -346,7 +364,7 @@ class Analysis(object):
         object equality.
         """
 
-        def check_slice(slice): # @ReservedAssignment
+        def check_slice(slice):  # @ReservedAssignment
 
             if isinstance(slice, ast.Index):
                 return check_node(slice.value)
@@ -448,7 +466,7 @@ class Analysis(object):
                 const, name = check_name(node.func)
 
                 # The function must have a name, and must be declared pure.
-                if (const != GLOBAL_CONST) or  (name not in self.pure_functions):
+                if (const != GLOBAL_CONST) or (name not in self.pure_functions):
                     return NOT_CONST
 
                 consts = [ ]
@@ -627,6 +645,7 @@ class PyAnalysis(ast.NodeVisitor):
     def visit_Continue(self, node):
         self.analysis.exit_loop()
 
+
 class CompilerCache(object):
     """
     Objects of this class are used to cache the compiliation of Python code.
@@ -700,8 +719,9 @@ ccache = CompilerCache()
 
 CACHE_FILENAME = "cache/pyanalysis.rpyb"
 
+
 def load_cache():
-    if renpy.game.args.compile: # @UndefinedVariable
+    if renpy.game.args.compile:  # @UndefinedVariable
         return
 
     try:
@@ -715,10 +735,14 @@ def load_cache():
     except:
         pass
 
+
 def save_cache():
     if not ccache.updated:
         return
 
+    if renpy.macapp:
+        return
+
     try:
         data = zlib.compress(dumps(ccache, 2), 9)
 
