@@ -35,6 +35,7 @@ import codecs
 # Script
 ################################################################################
 
+
 class ScriptTranslator(object):
 
     def __init__(self):
@@ -64,6 +65,10 @@ class ScriptTranslator(object):
         # that language.
         self.block = collections.defaultdict(list)
 
+        # A map from language to a list of TranslateEarlyBlock objects for
+        # that language.
+        self.early_block = collections.defaultdict(list)
+
         # A map from language to a list of TranslatePython objects for
         # that language.
         self.python = collections.defaultdict(list)
@@ -92,6 +97,7 @@ class ScriptTranslator(object):
 
         TranslatePython = renpy.ast.TranslatePython
         TranslateBlock = renpy.ast.TranslateBlock
+        TranslateEarlyBlock = renpy.ast.TranslateEarlyBlock
         Menu = renpy.ast.Menu
         Translate = renpy.ast.Translate
 
@@ -114,6 +120,11 @@ class ScriptTranslator(object):
                     self.languages.add(n.language)
                 self.python[n.language].append(n)
 
+            elif type_n is TranslateEarlyBlock:
+                if n.language is not None:
+                    self.languages.add(n.language)
+                self.early_block[n.language].append(n)
+
             elif type_n is TranslateBlock:
                 if n.language is not None:
                     self.languages.add(n.language)
@@ -174,6 +185,7 @@ class ScriptTranslator(object):
 
         return tl.block[0]
 
+
 def encode_say_string(s):
     """
     Encodes a string in the format used by Ren'Py say statements.
@@ -186,6 +198,7 @@ def encode_say_string(s):
 
     return "\"" + s + "\""
 
+
 class Restructurer(object):
 
     def __init__(self, children):
@@ -197,7 +210,7 @@ class Restructurer(object):
         if identifier in self.identifiers:
             return True
 
-        if identifier in renpy.game.script.translator.default_translates: # @UndefinedVariable
+        if identifier in renpy.game.script.translator.default_translates:  # @UndefinedVariable
             return True
 
         return False
@@ -285,6 +298,7 @@ class Restructurer(object):
 
         children[:] = new_children
 
+
 def restructure(children):
     Restructurer(children)
 
@@ -381,7 +395,9 @@ class StringTranslator(object):
 
         f.close()
 
+
 def add_string_translation(language, old, new, newloc):
+
     tl = renpy.game.script.translator
     stl = tl.strings[language]
     tl.languages.add(language)
@@ -389,6 +405,7 @@ def add_string_translation(language, old, new, newloc):
 
 Default = renpy.object.Sentinel("default")
 
+
 def translate_string(s, language=Default):
     """
     Translates interface string `s` to `language`. If `languages` is Default,
@@ -398,11 +415,12 @@ def translate_string(s, language=Default):
     if language is Default:
         language = renpy.game.preferences.language
 
-    stl = renpy.game.script.translator.strings[language] # @UndefinedVariable
+    stl = renpy.game.script.translator.strings[language]  # @UndefinedVariable
     return stl.translate(s)
 
+
 def write_updated_strings():
-    stl = renpy.game.script.translator.strings[renpy.game.preferences.language] # @UndefinedVariable
+    stl = renpy.game.script.translator.strings[renpy.game.preferences.language]  # @UndefinedVariable
     stl.write_updated_strings(renpy.game.preferences.language)
 
 
@@ -458,6 +476,7 @@ def load_rpt(fn):
     if old is not None:
         raise Exception("{0} string {1!r} does not have a translation.".format(language, old))
 
+
 def load_all_rpts():
     """
     Loads all .rpt files.
@@ -473,17 +492,18 @@ def load_all_rpts():
 
 style_backup = None
 
+
 def init_translation():
     """
     Called before the game starts.
     """
 
     global style_backup
-    style_backup = renpy.style.backup() # @UndefinedVariable
+    style_backup = renpy.style.backup()  # @UndefinedVariable
 
     load_all_rpts()
 
-    renpy.store._init_language() # @UndefinedVariable
+    renpy.store._init_language()  # @UndefinedVariable
 
 old_language = "language never set"
 
@@ -491,12 +511,16 @@ old_language = "language never set"
 # styles are run.
 deferred_styles = [ ]
 
+
 def old_change_language(tl, language):
 
     for i in deferred_styles:
         i.apply()
 
     def run_blocks():
+        for i in tl.early_block[language]:
+            renpy.game.context().run(i.block[0])
+
         for i in tl.block[language]:
             renpy.game.context().run(i.block[0])
 
@@ -505,12 +529,26 @@ def old_change_language(tl, language):
     for i in tl.python[language]:
         renpy.python.py_exec_bytecode(i.code.bytecode)
 
+    for i in renpy.config.language_callbacks[language]:
+        i()
+
 
 def new_change_language(tl, language):
 
+    renpy.config.init_system_styles()
+
     for i in tl.python[language]:
         renpy.python.py_exec_bytecode(i.code.bytecode)
 
+    def run_blocks():
+        for i in tl.early_block[language]:
+            renpy.game.context().run(i.block[0])
+
+    renpy.game.invoke_in_new_context(run_blocks)
+
+    for i in renpy.config.language_callbacks[language]:
+        i()
+
     for i in deferred_styles:
         i.apply()
 
@@ -520,6 +558,7 @@ def new_change_language(tl, language):
 
     renpy.game.invoke_in_new_context(run_blocks)
 
+
 def change_language(language):
     """
     :doc: translation_functions
@@ -534,8 +573,8 @@ def change_language(language):
 
     tl = renpy.game.script.translator
 
-    renpy.style.restore(style_backup) # @UndefinedVariable
-    renpy.style.rebuild() # @UndefinedVariable
+    renpy.style.restore(style_backup)  # @UndefinedVariable
+    renpy.style.rebuild()  # @UndefinedVariable
 
     for i in renpy.config.translate_clean_stores:
         renpy.python.clean_store(i)
@@ -555,7 +594,7 @@ def change_language(language):
         renpy.exports.free_memory()
 
         # Rebuild the styles.
-        renpy.style.rebuild() # @UndefinedVariable
+        renpy.style.rebuild()  # @UndefinedVariable
 
         old_language = language
 
@@ -568,6 +607,7 @@ def change_language(language):
     if language != old_language:
         renpy.exports.block_rollback()
 
+
 def check_language():
     """
     Checks to see if the language has changed. If it has, jump to the start
@@ -584,11 +624,12 @@ def check_language():
         tid = ctx.translate_identifier
 
         if tid is not None:
-            node = renpy.game.script.translator.lookup_translate(tid) # @UndefinedVariable
+            node = renpy.game.script.translator.lookup_translate(tid)  # @UndefinedVariable
 
             if node is not None:
                 raise renpy.game.JumpException(node.name)
 
+
 def known_languages():
     """
     :doc: translation_functions
@@ -597,4 +638,4 @@ def known_languages():
     language, None.
     """
 
-    return renpy.game.script.translator.languages # @UndefinedVariable
+    return { i for i in renpy.game.script.translator.languages if i is not None }  # @UndefinedVariable
